/*
 * Java
 *
 * Copyright 2018-2019 MicroEJ Corp. All rights reserved.
 * For demonstration purpose only.
 * MicroEJ Corp. PROPRIETARY. Use is subject to license terms.
 */
package com.microej.demo.thermorest.model;

import ej.bon.Timer;
import ej.bon.TimerTask;
import ej.components.dependencyinjection.ServiceLoaderFactory;

/**
 * A thermostat model changing its temperature by 0.5° each second to reach the target temperature. This is an example
 * of an Model implementation for the demonstration purpose.
 */
public class AutomaticThermostatModel extends ThermostatModel {

	private static final long DELAY = 1000;
	private static final float STEP = 0.5f;

	private TimerTask task;

	/**
	 * Instantiates an {@link AutomaticThermostatModel}.
	 */
	public AutomaticThermostatModel() {
		start();
	}

	@Override
	public void setTargetTemperature(float target) {
		if (target != getTargetTemperature()) {
			super.setTargetTemperature(target);
			start();
		}
	}

	@Override
	public void setTemperature(float temperature) {
		if (temperature != getTemperature()) {
			super.setTemperature(temperature);
			start();
		}
	}

	private synchronized void start() {
		if (this.task == null && getTemperature() != getTargetTemperature()) {
			this.task = new TimerTask() {

				@Override
				public void run() {
					float temperature = getTemperature();
					float target = getTargetTemperature();
					if (temperature > target) {
						setTemperature(Math.max(target, temperature - STEP));
					} else if (temperature < target) {
						setTemperature(Math.min(target, temperature + STEP));
					}
					synchronized (AutomaticThermostatModel.this) {
						AutomaticThermostatModel.this.task = null;
						start();
					}
				}
			};
			ServiceLoaderFactory.getServiceLoader().getService(Timer.class, Timer.class).schedule(this.task, DELAY);
		}
	}
}
