/*
 * Java
 *
 * Copyright 2018-2019 MicroEJ Corp. All rights reserved.
 * This library is provided in source code for use, modification and test, subject to license terms.
 * Any modification of the source code will break MicroEJ Corp. warranties on the whole library.
 */
package com.microej.profiling.internal.snapshot;

/**
 * A pair of {@link PrintableSnapshot}.
 */
public class PrintablePair {
	private final PrintableSnapshot reference;
	private PrintableSnapshot second;

	/**
	 * Instantiates a {@link PrintablePair}.
	 *
	 * @param reference
	 *            the snapshot used as reference.
	 */
	public PrintablePair(PrintableSnapshot reference) {
		this.reference = reference;
		this.second = reference;
	}

	/**
	 *
	 * Instantiates a {@link PrintablePair}.
	 *
	 * @param snapshot
	 *            the snapshot used as reference.
	 * @param level
	 *            the stack's level.
	 */
	public PrintablePair(Snapshot snapshot, Integer level) {
		this(new PrintableSnapshot(snapshot, level.intValue()));
	}

	/**
	 * Sets the second element of the {@link PrintablePair}.
	 *
	 * @param second
	 *            the second {@link PrintableSnapshot}.
	 */
	public void setSecond(PrintableSnapshot second) {
		this.second = second;
	}

	/**
	 * Gets the second {@link PrintableSnapshot}.
	 *
	 * @return the second {@link PrintableSnapshot}.
	 */
	public PrintableSnapshot getSecond() {
		return this.second;
	}

	/**
	 * Gets the {@link PrintableSnapshot} used as reference.
	 *
	 * @return the {@link PrintableSnapshot} used as reference.
	 */
	public PrintableSnapshot getReference() {
		return this.reference;
	}
}