/*
 * Java
 *
 * Copyright 2015-2019 MicroEJ Corp. All rights reserved.
 * This library is provided in source code for use, modification and test, subject to license terms.
 * Any modification of the source code will break MicroEJ Corp. warranties on the whole library.
 */
package ej.style.font.filter;

import ej.microui.display.Font;

/**
 * Implementation that filters fonts on their descriptor.
 * <p>
 * A font is selected if its descriptor starts with the filter font family.
 */
public class FontFamilyFilter implements Filter<Font> {

	private String fontFamily;

	/**
	 * Creates a font filter that filters font on the given font family.
	 *
	 * @param fontFamily
	 *            the font family to use for the filter.
	 */
	public FontFamilyFilter(String fontFamily) {
		this.fontFamily = fontFamily;
	}

	/**
	 * Sets the font family.
	 *
	 * @param fontFamily
	 *            the font family to use for the filter.
	 */
	public void setFontFamily(String fontFamily) {
		this.fontFamily = fontFamily;
	}

	@Override
	public boolean accept(Font element) {
		String fontName = element.getDescriptor();
		return fontName.startsWith(this.fontFamily);
	}

}
