/*
 * Java
 *
 * Copyright 2015-2019 MicroEJ Corp. All rights reserved.
 * This library is provided in source code for use, modification and test, subject to license terms.
 * Any modification of the source code will break MicroEJ Corp. warranties on the whole library.
 */
package ej.style.outline;

import ej.annotation.Nullable;
import ej.microui.display.GraphicsContext;
import ej.style.container.Rectangle;

/**
 * Outline that have the same thickness for all edges.
 */
public class SimpleOutline implements Outline {

	private int thickness;

	/**
	 * Creates an empty simple outline (0 pixel thickness).
	 */
	public SimpleOutline() {
	}

	/**
	 * Creates a simple outline specifying its thickness.
	 *
	 * @param thickness
	 *            the thickness to set.
	 */
	public SimpleOutline(int thickness) {
		this.thickness = thickness;
	}

	/**
	 * Sets the thickness.
	 *
	 * @param thickness
	 *            the thickness to set.
	 */
	public void setThickness(int thickness) {
		this.thickness = thickness;
	}

	/**
	 * Gets the thickness.
	 *
	 * @return the thickness.
	 */
	public int getThickness() {
		return this.thickness;
	}

	@Override
	public void wrap(Rectangle rectangle) {
		int thickness = this.thickness;
		rectangle.update(-thickness, -thickness, thickness << 1, thickness << 1);
	}

	@Override
	public void unwrap(Rectangle rectangle) {
		int thickness = this.thickness;
		rectangle.update(thickness, thickness, -thickness << 1, -thickness << 1);
	}

	@Override
	public void apply(GraphicsContext g, Rectangle rectangle) {
		g.translate(this.thickness, this.thickness);
		unwrap(rectangle);
		g.clipRect(0, 0, rectangle.getWidth(), rectangle.getHeight());
	}

	@Override
	public boolean equals(@Nullable Object obj) {
		if (obj instanceof SimpleOutline) {
			SimpleOutline outline = (SimpleOutline) obj;
			return this.thickness == outline.thickness;
		}
		return false;
	}

	@Override
	public int hashCode() {
		// Since the fields are not final, they can't be used to compute a constant hashcode.
		return 0;
	}

}
