/*
 * Java
 *
 * Copyright 2015-2019 MicroEJ Corp. All rights reserved.
 * This library is provided in source code for use, modification and test, subject to license terms.
 * Any modification of the source code will break MicroEJ Corp. warranties on the whole library.
 */
package ej.style.selector;

import ej.annotation.Nullable;
import ej.style.Element;
import ej.style.Selector;

/**
 * A last child selector selects by checking if an element is the last child of its parent.
 * <p>
 * Equivalent to <code>:last-child</code> selector in CSS. Its specificity is (0,0,1,0).
 *
 * @see Element#getParentElement()
 * @see SpecificityHelper
 */
public class LastChildSelector implements Selector {

	/**
	 * Last child selector singleton to avoid creating several ones.
	 */
	public static final LastChildSelector LAST_CHILD_SELECTOR = new LastChildSelector();

	/**
	 * Creates a last child selector.
	 */
	public LastChildSelector() {
	}

	@Override
	public boolean fit(Element element) {
		Element parentElement = element.getParentElement();

		return parentElement != null && parentElement.getChild(parentElement.getChildrenCount() - 1) == element;
	}

	@Override
	public int getSpecificity() {
		return SpecificityHelper.getSpecificity(0, 0, 1, 0);
	}

	@Override
	public int hashCode() {
		return 0;
	}

	@Override
	public boolean equals(@Nullable Object obj) {
		return (obj instanceof LastChildSelector);
	}

}
