/*
 * Java
 *
 * Copyright 2014-2015 IS2T. All rights reserved.
 * Use of this source code is governed by a BSD-style license that can be found at http://www.is2t.com/open-source-bsd-license/.
 */
package ej.wadapps.management;

import ej.observable.Observable;
import ej.observable.Observer;
import ej.wadapps.app.BackgroundService;

/**
 * Holds a list of background services.
 */
public interface BackgroundServicesList {

	/**
	 * Adds an observer to this background services list.
	 * <p>
	 * The observer will be notified when the background services list will be modified.
	 *
	 * @param observer
	 *            an observer to be added.
	 * @throws NullPointerException
	 *             if the given observer is <code>null</code>.
	 * @see Observable#addObserver(Observer)
	 * @see #add(BackgroundService)
	 * @see #remove(BackgroundService)
	 */
	void addObserver(Observer observer) throws NullPointerException;

	/**
	 * Deletes an observer.
	 * <p>
	 * The observer will no longer be notified of this background services list modification.
	 *
	 * @param observer
	 *            an observer to be removed.
	 * @see Observable#deleteObserver(Observer)
	 */
	void deleteObserver(Observer observer);

	/**
	 * Adds a background.
	 * <p>
	 * The observers will be notified with the background as argument.
	 *
	 * @param background
	 *            the background to be added.
	 */
	void add(BackgroundService background);

	/**
	 * Removes a background.
	 * <p>
	 * The observers are notified with the background as argument.
	 *
	 * @param background
	 *            the background to be removed.
	 */
	void remove(BackgroundService background);

	/**
	 * Gets all registered background services.
	 *
	 * @return all background services.
	 */
	BackgroundService[] getBackgroundServices();

}
