/*
 * Java
 *
 * Copyright 2016-2019 MicroEJ Corp. All rights reserved.
 * This library is provided in source code for use, modification and test, subject to license terms.
 * Any modification of the source code will break MicroEJ Corp. warranties on the whole library.
 */
package ej.widget.navigation.navigator;

import ej.widget.navigation.Navigator;
import ej.widget.navigation.page.ClassNameURLResolver;
import ej.widget.navigation.page.Page;

/**
 * Manages the navigation between several pages, from one page to the next and/or the previous.
 * <p>
 * References to pages are kept for faster navigation.
 * 
 * @deprecated see {@link ej.widget.container.transition.TransitionContainer}.
 */
@Deprecated
public class ChainedNavigatorReference extends Navigator {

	private final Page[] pages;
	private final boolean circular;
	private int currentIndex;

	/**
	 * Creates a navigator for chained pages.
	 *
	 * @param pages
	 *            the pages.
	 * @param circular
	 *            <code>true</code> to go from the first page to the last one by going backward and to go from the last
	 *            page to the first one by going forward,<code>false</code> otherwise.
	 * @see ClassNameURLResolver
	 */
	public ChainedNavigatorReference(Page[] pages, boolean circular) {
		int length = pages.length;
		this.pages = new Page[length];
		System.arraycopy(pages, 0, this.pages, 0, length);
		this.circular = circular;
		show(getPage(this.currentIndex), true);
	}

	private Page getPage(int index) {
		return this.pages[index];
	}

	@Override
	public boolean canGoBackward() {
		return this.circular || this.currentIndex != 0;
	}

	@Override
	protected Page getPreviousPage() {
		return getPage(getPreviousIndex());
	}

	@Override
	public void goBackward() {
		this.currentIndex = getPreviousIndex();
		show(getPage(this.currentIndex), false);
	}

	private int getPreviousIndex() {
		if (this.currentIndex == 0) {
			if (this.circular) {
				return this.pages.length - 1;
			} else {
				throw new IllegalArgumentException();
			}
		} else {
			return this.currentIndex - 1;
		}
	}

	@Override
	public boolean canGoForward() {
		return this.circular || this.currentIndex != this.pages.length - 1;
	}

	@Override
	protected Page getNextPage() {
		return getPage(getNextIndex());
	}

	@Override
	public void goForward() {
		this.currentIndex = getNextIndex();
		show(getPage(this.currentIndex), true);
	}

	private int getNextIndex() {
		if (this.currentIndex == this.pages.length - 1) {
			if (this.circular) {
				return 0;
			} else {
				throw new IllegalArgumentException();
			}
		} else {
			return this.currentIndex + 1;
		}
	}

}
